@@ -1,7 +1,7 @@
 use v6;
-use PDF::Font; #::CIDFontType0;
+use PDF::Font::CIDFontType0;
 
 class PDF::Font::CIDFontType2
-    is PDF::Font { #::CIDFontType0 {
+    is PDF::Font::CIDFontType0 {
     # see [PDF 1.7 TABLE 5.14 - has identical structure to CIDFontType0]
 }
